@@ -1,5 +1,5 @@
 package IO::Capture::Stdout::Extended;
-$VERSION = 0.03; # as of 03/01/2005
+$VERSION = 0.04; # as of 03/13/2005
 use strict;
 use warnings;
 use base 'IO::Capture::Stdout';
@@ -38,6 +38,24 @@ sub _matches_engine {
     my @matches = $str =~ m/$regex/g;
 }
 
+sub all_screen_lines {
+    my $self = shift;
+    my @screen_lines;
+    my $str = '';
+
+    for my $statement (@{$self->{'IO::Capture::messages'}}) {
+        if ($statement =~ /\n$/s) {
+            $str .= $statement;
+	    push(@screen_lines, $str);
+	    $str = '';
+        } else {
+            $str .= $statement;
+        }
+    }
+    push(@screen_lines, $str) if $str;
+    return wantarray ? @screen_lines : scalar(@screen_lines);
+}
+
 
 1;
 
@@ -75,6 +93,12 @@ IO::Capture::Stdout::Extended - Extend functionality of IO::Capture::Stdout
     # return reference to array holding list of pattern matches
     $matchesref = $capture->matches_ref($regex);
 
+    # scalar context:  return number of 'screen' lines printed
+    $screen_lines = $capture->all_screen_lines();
+
+    # list context:  return list of 'screen' lines printed
+    @all_screen_lines = $capture->all_screen_lines();
+
 =head1 DESCRIPTION
 
 IO::Capture::Stdout::Extended is a collection of subroutines which 
@@ -101,6 +125,8 @@ such as C<ok()>, C<is()> and C<like()>.  The examples below illustrate
 that objective.  Suggestions are welcome for additional methods 
 which would fulfill that objective.
 
+=head2 Individual Methods
+
 =head3 C<grep_print_statements()>
 
 =over 4
@@ -225,6 +251,49 @@ illustrated by the following:
     is($capture->statements, 8, 
         "number of print statements is correct");
 
+This pitfall can be avoided by using C<all_screen_lines()> below.
+
+=head3 C<all_screen_lines()>
+
+=over 4
+
+=item * Scalar Context
+
+Returns the number of lines which would normally be counted by eye on 
+STDOUT.  This number is less than or equal to the number of C<print()> 
+statements found in the captured output and avoids the 'pitfall' found
+when using C<statements()> above.
+
+    $capture->start();
+    print_greek_long();
+    $capture->stop();
+    $screen_lines = $capture->all_screen_lines;
+    is($screen_lines, 4, "correct no. of lines printed to screen");
+
+=item * List Context
+
+Returns an array holding lines as normally viewed on STDOUT.  The size
+of this array is less than or equal to the number of C<print()>
+statements found in the captured output and avoids the 'pitfall' found
+when using C<statements()> above.
+
+    $capture->start();
+    print_greek_long();
+    $capture->stop();
+    @all_screen_lines = $capture->all_screen_lines;
+    is($all_screen_lines[0], 
+        "alpha\n", 
+        "line correctly printed to screen");
+    is($all_screen_lines[1], 
+        "beta\n", 
+        "line correctly printed to screen");
+
+Any newline (C<\n>) appearing at the end of a screen line is I<included>
+in the list of lines returned by this method, I<i.e.,> the lines are
+unchomped.
+
+=back
+
 =head3 C<matches()>
 
 =over 4
